# coding: utf-8

# flake8: noqa

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2020.02.27
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.1.1"

# import apis into sdk package
from agilicus.api.application_services_api import ApplicationServicesApi
from agilicus.api.applications_api import ApplicationsApi
from agilicus.api.files_api import FilesApi
from agilicus.api.groups_api import GroupsApi
from agilicus.api.logs_query_api import LogsQueryApi
from agilicus.api.metrics_api import MetricsApi
from agilicus.api.organisations_api import OrganisationsApi
from agilicus.api.services_api import ServicesApi
from agilicus.api.tokens_api import TokensApi
from agilicus.api.users_api import UsersApi
from agilicus.api.view_audit_records_api import ViewAuditRecordsApi
from agilicus.api.whoami_api import WhoamiApi

# import ApiClient
from agilicus.api_client import ApiClient
from agilicus.configuration import Configuration
from agilicus.exceptions import OpenApiException
from agilicus.exceptions import ApiTypeError
from agilicus.exceptions import ApiValueError
from agilicus.exceptions import ApiKeyError
from agilicus.exceptions import ApiException
# import models into sdk package
from agilicus.models.application import Application
from agilicus.models.application_assignment import ApplicationAssignment
from agilicus.models.application_service import ApplicationService
from agilicus.models.application_service_assignment import ApplicationServiceAssignment
from agilicus.models.audit_query_result import AuditQueryResult
from agilicus.models.audit_query_result_results import AuditQueryResultResults
from agilicus.models.definition import Definition
from agilicus.models.environment import Environment
from agilicus.models.environment_config import EnvironmentConfig
from agilicus.models.file import File
from agilicus.models.file_summary import FileSummary
from agilicus.models.file_upload import FileUpload
from agilicus.models.group import Group
from agilicus.models.group_data import GroupData
from agilicus.models.group_member import GroupMember
from agilicus.models.group_member_add import GroupMemberAdd
from agilicus.models.group_member_data import GroupMemberData
from agilicus.models.host_permissions import HostPermissions
from agilicus.models.host_permissions_allowed_list import HostPermissionsAllowedList
from agilicus.models.host_permissions_query_parameters import HostPermissionsQueryParameters
from agilicus.models.log import Log
from agilicus.models.num_active_users import NumActiveUsers
from agilicus.models.num_active_users_active_users import NumActiveUsersActiveUsers
from agilicus.models.organisation import Organisation
from agilicus.models.organisation_admin import OrganisationAdmin
from agilicus.models.raw_token import RawToken
from agilicus.models.role import Role
from agilicus.models.roles_update import RolesUpdate
from agilicus.models.rule import Rule
from agilicus.models.rule_body import RuleBody
from agilicus.models.rule_body_json import RuleBodyJson
from agilicus.models.rule_query_parameters import RuleQueryParameters
from agilicus.models.service import Service
from agilicus.models.storage_region import StorageRegion
from agilicus.models.token import Token
from agilicus.models.token_request import TokenRequest
from agilicus.models.token_request_time_validity import TokenRequestTimeValidity
from agilicus.models.token_request_validity import TokenRequestValidity
from agilicus.models.token_revoke import TokenRevoke
from agilicus.models.top_users import TopUsers
from agilicus.models.top_users_top_n_users import TopUsersTopNUsers
from agilicus.models.user import User
from agilicus.models.user_identity import UserIdentity
from agilicus.models.user_info import UserInfo
from agilicus.models.user_member_of import UserMemberOf
from agilicus.models.user_summary import UserSummary




# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['agilicus', 'agilicus.api', 'agilicus.models']

package_data = \
{'': ['*']}

install_requires = \
['certifi>=14.05.14', 'python_dateutil>2.5.3', 'six>1.10', 'urllib3>1.15.1']

setup_kwargs = {
    'name': 'agilicus',
    'version': '1.1.1',
    'description': 'Agilicus SDK',
    'long_description': '## Agilicus SDK (Python)\n\n[generated](agilicus_README.md)\n',
    'author': 'Don Bowman',
    'author_email': 'don@agilicus.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from agilicus.api.application_services_api import ApplicationServicesApi
from agilicus.api.applications_api import ApplicationsApi
from agilicus.api.files_api import FilesApi
from agilicus.api.groups_api import GroupsApi
from agilicus.api.logs_query_api import LogsQueryApi
from agilicus.api.metrics_api import MetricsApi
from agilicus.api.organisations_api import OrganisationsApi
from agilicus.api.services_api import ServicesApi
from agilicus.api.tokens_api import TokensApi
from agilicus.api.users_api import UsersApi
from agilicus.api.view_audit_records_api import ViewAuditRecordsApi
from agilicus.api.whoami_api import WhoamiApi
